import { Request, Response } from 'express'
import {values_present} from './common'

export enum Type {
	Text = 'text',
	Voice = 'voice',
}

function valid_channel(ch: string) : boolean {
	return ch === Type.Text || ch === Type.Voice
}

export async function list(req: Request, res: Response, db) : Promise<void> {
	const channels = await db.one('SELECT * from channels')
	res.send({path: req.path, data: channels.value})
}

export async function create(req: Request, res: Response) : Promise<void> {
	const { name, description, type } = req.query
	if (values_present([name, description, type])|| !valid_channel(type.toString()) ) {
		res.status(400).send({ error: 'Invalid query string params' })
		return
	}
	res.send({
		id: 123,
		name: name,
		description: description,
		type: type
	})
}
